@@ -64,8 +64,8 @@ class startControl(QThread):
         RIG_PORT = HAMLIB_PORT
         TCP_IP = self.hamlibIPv
         print (TCP_IP, HAMLIB_PORT, self.gqrxIPv, GQRX_PORT)
-        sockGqrx = socket.create_connection((self.gqrxIPv, GQRX_PORT))
-        #sockHamlib = socket.create_connection((TCP_IP, HAMLIB_PORT))
+        #sockGqrx = socket.create_connection((self.gqrxIPv, GQRX_PORT))
+        sockHamlib = socket.create_connection((TCP_IP, HAMLIB_PORT))
             #sockHamlib = socket.socket(socket.AF_INET, socket.SOCK_STREAM) 
             # Bind the socket to the port
             #server_address1 = (TCP_IP, HAMLIB_PORT)
